﻿function map(lat, lon, zoom) {
  var attribution = 'Map data &copy; '
    +'<a href="http://openstreetmap.org">'
    +'OpenStreetMap</a> contributors, '
    +'<a href="http://opendatacommons.org/licenses/odbl/">ODbL</a>';
  // Kartenlayer
  var mapnik = L.tileLayer('http://tile.openstreetmap.org/{z}/{x}/{y}.png',
  {
    attribution: attribution,
    maxZoom: 18
  });
  // Kartenlayer
  var hikebike = L.tileLayer('http://toolserver.org/tiles/hikebike/{z}/{x}/{y}.png',
  {
    attribution: attribution,
    maxZoom: 18
  });
  // Kartenlayer (Overlay)
  var hill = L.tileLayer('http://toolserver.org/~cmarqu/hill/{z}/{x}/{y}.png',
  {
    attribution: attribution,
    maxZoom: 18
  });
  // Eigentliche Karte
  var myMap = L.map('map', {
    center: new L.LatLng(lat, lon),
    zoom: zoom,
    layers: [mapnik, hikebike],
  });
  // Marker setzen
  var marker1 = L.marker([50.823, 12.926]);
  // Beim Anklicken angezeigter Inhalt:
  marker1.bindPopup(
    '<b>Südbahnhof</b>'
  );
  // Eigener Marker
  var starIcon = L.icon({
    iconUrl: 'star.png',
    iconSize: [32, 32],
    iconAnchor: [16, 16],
    popupAnchor: [0,-16],
  });
  var marker2 = L.marker([50.8135, 12.9293], {icon: starIcon});
  // Beim Anklicken angezeigter Inhalt:
  marker2.bindPopup(
    '<b>Chemnitzer Linux-Tage<br/><img src="wahl.png"/>'
  );
  // Zusammenfassen zu einer Gruppe - gemeinsam ein-/ausschalten
  var markers = L.layerGroup([marker1, marker2]);
  // Höhenschatterung und marker anzeigen
  hill.addTo(myMap);
  markers.addTo(myMap);
  // Liste der Kartenlayer (Basiskarten)
  var baseMaps = {
    "Mapnik": mapnik,
    "Hike & Bike": hikebike,
  };
  // Liste der Overlays
  var overlayMaps = {
    'Höhenschattierung': hill,
    'Marker': markers,
  };
  var control = L.control.layers(baseMaps, overlayMaps);
  control.addTo(myMap);
  // Kilometerskala
  L.control.scale().addTo(myMap);
  // Track laden und darstellen
  drawGpx(myMap, control, 'mytrack.gpx');
}

function drawGpx(map, control, gpxfile) {
  // Download Track
  var xmlhttp = new XMLHttpRequest();
  xmlhttp.open('GET', gpxfile, true);
  xmlhttp.overrideMimeType('application/xml');
  xmlhttp.onreadystatechange = function () {
    if (xmlhttp.readyState != 4) return;
    if (xmlhttp.status != 0 && xmlhttp.status != 200) return;
    // Download ok - Verarbeitung
    // Für Route rtept, für Wegpunkte wpt verwenden
    var nodes = xmlhttp.responseXML.getElementsByTagName('trkpt');
    drawNodes(map, control, nodes);
  }
  xmlhttp.send();
}

// Callback nach Track Download
function drawNodes(map, control, nodes) {
  // Polyline erzeugen
  poly = [];
  for (var i = 0; i < nodes.length; i++) {
    var lat = parseFloat(nodes[i].getAttribute('lat'));
    var lon = parseFloat(nodes[i].getAttribute('lon'));
    poly.push(new L.LatLng(lat, lon));
  }
  // Track darstellen
  var track = new L.Polyline(poly, {
    color: '#ff00ff',
    weight: 3,
    opacity: 1.0,
  }).addTo(map);
  // Bei Anklicken des Tracks anzeigen
  track.bindPopup("Trackbeschreibung");
  // Track abschaltbar machen
  control.addOverlay(track, 'Track');
}
